==> cdi-tck-2.0.6-dist.zip: org/jboss/cdi/tck/interceptors/tests/order/overriden/lifecycleCallback/wrapped/WrappingExtension.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.interceptors.tests.order.overriden.lifecycleCallback.wrapped;

import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.AnnotatedType;
import javax.enterprise.inject.spi.Extension;
import javax.enterprise.inject.spi.ProcessAnnotatedType;

import org.jboss.cdi.tck.util.ForwardingAnnotatedType;

public class WrappingExtension implements Extension {

    public <T extends Bird> void observeBirdTypes(@Observes ProcessAnnotatedType<T> event) {

        final AnnotatedType<T> annotatedType = event.getAnnotatedType();
        event.setAnnotatedType(new ForwardingAnnotatedType<T>() {
            @Override
            public AnnotatedType<T> delegate() {
                return annotatedType;
            }
        });
    }
}

==> cdi-tck-3.0.0-dist.zip: org/jboss/cdi/tck/interceptors/tests/order/overriden/lifecycleCallback/wrapped/WrappingExtension.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.interceptors.tests.order.overriden.lifecycleCallback.wrapped;

import jakarta.enterprise.event.Observes;
import jakarta.enterprise.inject.spi.AnnotatedType;
import jakarta.enterprise.inject.spi.Extension;
import jakarta.enterprise.inject.spi.ProcessAnnotatedType;

import org.jboss.cdi.tck.util.ForwardingAnnotatedType;

public class WrappingExtension implements Extension {

    public <T extends Bird> void observeBirdTypes(@Observes ProcessAnnotatedType<T> event) {

        final AnnotatedType<T> annotatedType = event.getAnnotatedType();
        event.setAnnotatedType(new ForwardingAnnotatedType<T>() {
            @Override
            public AnnotatedType<T> delegate() {
                return annotatedType;
            }
        });
    }
}
